@@ -9,7 +9,6 @@ class NavigationException(Exception):
 
 
 def parser_navigate(parser_result, path, current_path=None):
-
     if isinstance(path, str):
         if path == '':
             return parser_result
@@ -35,11 +34,25 @@ def parser_navigate(parser_result, path, current_path=None):
     ))
 
 
-def parse_parser(parser, data=None):
+def _try_add_parser_attribute(data, parser, attribname):
+    attribval = getattr(parser, attribname, None)
+    if attribval is None:
+        return
 
+    if not isinstance(attribval, str):
+        return
+
+    if len(attribval) > 0:
+        data[attribname] = attribval
+
+
+def parse_parser(parser, data=None, **kwargs):
     if data is None:
         data = {'name': '', 'usage': parser.format_usage()}
 
+    _try_add_parser_attribute(data, parser, 'description')
+    _try_add_parser_attribute(data, parser, 'epilog')
+
     for action in parser._get_positional_actions():
 
         if isinstance(action, _HelpAction):
@@ -58,7 +71,7 @@ def parse_parser(parser, data=None):
                     'help': helps[name] if name in helps else '',
                     'usage': subaction.format_usage()
                 }
-                parse_parser(subaction, subdata)
+                parse_parser(subaction, subdata, **kwargs)
 
                 if not 'children' in data:
                     data['children'] = []
@@ -74,6 +87,8 @@ def parse_parser(parser, data=None):
             'help': action.help or ''
         })
 
+    show_defaults = (not 'skip_default_values' in kwargs) or (kwargs['skip_default_values'] == False)
+
     for action in parser._get_optional_actions():
 
         if isinstance(action, _HelpAction):
@@ -84,7 +99,7 @@ def parse_parser(parser, data=None):
 
         data['options'].append({
             'name': action.option_strings,
-            'default': action.default,
+            'default': action.default if show_defaults else '==SUPPRESS==',
             'help': action.help or ''
         })
 
